@@ -85,47 +85,47 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_kms
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class PrivateBucket(
-    aws_cdk.aws_s3.Bucket,
+    _aws_cdk_aws_s3_ceddda9d.Bucket,
     metaclass=jsii.JSIIMeta,
     jsii_type="@pepperize/cdk-private-bucket.PrivateBucket",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+        access_control: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl] = None,
         auto_delete_objects: typing.Optional[builtins.bool] = None,
-        block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
+        block_public_access: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess] = None,
         bucket_key_enabled: typing.Optional[builtins.bool] = None,
         bucket_name: typing.Optional[builtins.str] = None,
-        cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
-        encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        cors: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.CorsRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+        encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
         enforce_ssl: typing.Optional[builtins.bool] = None,
         event_bridge_enabled: typing.Optional[builtins.bool] = None,
-        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
-        inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
-        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
-        metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
-        object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
+        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration, typing.Dict[builtins.str, typing.Any]]]] = None,
+        inventories: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.Inventory, typing.Dict[builtins.str, typing.Any]]]] = None,
+        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
+        object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        server_access_logs_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
         server_access_logs_prefix: typing.Optional[builtins.str] = None,
         transfer_acceleration: typing.Optional[builtins.bool] = None,
         versioned: typing.Optional[builtins.bool] = None,
         website_error_document: typing.Optional[builtins.str] = None,
         website_index_document: typing.Optional[builtins.str] = None,
-        website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
-        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
+        website_redirect: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.RedirectTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.RoutingRule, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -157,38 +157,7 @@ class PrivateBucket(
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
-                auto_delete_objects: typing.Optional[builtins.bool] = None,
-                block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
-                bucket_key_enabled: typing.Optional[builtins.bool] = None,
-                bucket_name: typing.Optional[builtins.str] = None,
-                cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
-                encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-                enforce_ssl: typing.Optional[builtins.bool] = None,
-                event_bridge_enabled: typing.Optional[builtins.bool] = None,
-                intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
-                inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
-                lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
-                metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
-                object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
-                public_read_access: typing.Optional[builtins.bool] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                server_access_logs_prefix: typing.Optional[builtins.str] = None,
-                transfer_acceleration: typing.Optional[builtins.bool] = None,
-                versioned: typing.Optional[builtins.bool] = None,
-                website_error_document: typing.Optional[builtins.str] = None,
-                website_index_document: typing.Optional[builtins.str] = None,
-                website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
-                website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__12c21179f9e7bb44a50659259407e96dc6e1f1b6b4428f047f629d9fe45b16e0)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PrivateBucketProps(
@@ -224,7 +193,7 @@ class PrivateBucket(
 
 @jsii.data_type(
     jsii_type="@pepperize/cdk-private-bucket.PrivateBucketProps",
-    jsii_struct_bases=[aws_cdk.aws_s3.BucketProps],
+    jsii_struct_bases=[_aws_cdk_aws_s3_ceddda9d.BucketProps],
     name_mapping={
         "access_control": "accessControl",
         "auto_delete_objects": "autoDeleteObjects",
@@ -253,35 +222,35 @@ class PrivateBucket(
         "website_routing_rules": "websiteRoutingRules",
     },
 )
-class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
+class PrivateBucketProps(_aws_cdk_aws_s3_ceddda9d.BucketProps):
     def __init__(
         self,
         *,
-        access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+        access_control: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl] = None,
         auto_delete_objects: typing.Optional[builtins.bool] = None,
-        block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
+        block_public_access: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess] = None,
         bucket_key_enabled: typing.Optional[builtins.bool] = None,
         bucket_name: typing.Optional[builtins.str] = None,
-        cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
-        encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        cors: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.CorsRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+        encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
         enforce_ssl: typing.Optional[builtins.bool] = None,
         event_bridge_enabled: typing.Optional[builtins.bool] = None,
-        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
-        inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
-        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
-        metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
-        object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
+        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration, typing.Dict[builtins.str, typing.Any]]]] = None,
+        inventories: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.Inventory, typing.Dict[builtins.str, typing.Any]]]] = None,
+        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
+        object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
-        removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+        server_access_logs_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
         server_access_logs_prefix: typing.Optional[builtins.str] = None,
         transfer_acceleration: typing.Optional[builtins.bool] = None,
         versioned: typing.Optional[builtins.bool] = None,
         website_error_document: typing.Optional[builtins.str] = None,
         website_index_document: typing.Optional[builtins.str] = None,
-        website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
-        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
+        website_redirect: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.RedirectTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.RoutingRule, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param access_control: Specifies a canned ACL that grants predefined permissions to the bucket. Default: BucketAccessControl.PRIVATE
@@ -311,38 +280,9 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
         if isinstance(website_redirect, dict):
-            website_redirect = aws_cdk.aws_s3.RedirectTarget(**website_redirect)
+            website_redirect = _aws_cdk_aws_s3_ceddda9d.RedirectTarget(**website_redirect)
         if __debug__:
-            def stub(
-                *,
-                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
-                auto_delete_objects: typing.Optional[builtins.bool] = None,
-                block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
-                bucket_key_enabled: typing.Optional[builtins.bool] = None,
-                bucket_name: typing.Optional[builtins.str] = None,
-                cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
-                encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-                enforce_ssl: typing.Optional[builtins.bool] = None,
-                event_bridge_enabled: typing.Optional[builtins.bool] = None,
-                intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
-                inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
-                lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
-                metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
-                object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
-                public_read_access: typing.Optional[builtins.bool] = None,
-                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-                server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                server_access_logs_prefix: typing.Optional[builtins.str] = None,
-                transfer_acceleration: typing.Optional[builtins.bool] = None,
-                versioned: typing.Optional[builtins.bool] = None,
-                website_error_document: typing.Optional[builtins.str] = None,
-                website_index_document: typing.Optional[builtins.str] = None,
-                website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
-                website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ef6f15d7c98db0989a25fa7ab8edef4a7fd55f4e92e2f77044d0f0c4ca58d2b)
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
             check_type(argname="argument auto_delete_objects", value=auto_delete_objects, expected_type=type_hints["auto_delete_objects"])
             check_type(argname="argument block_public_access", value=block_public_access, expected_type=type_hints["block_public_access"])
@@ -368,7 +308,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
             check_type(argname="argument website_index_document", value=website_index_document, expected_type=type_hints["website_index_document"])
             check_type(argname="argument website_redirect", value=website_redirect, expected_type=type_hints["website_redirect"])
             check_type(argname="argument website_routing_rules", value=website_routing_rules, expected_type=type_hints["website_routing_rules"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if access_control is not None:
             self._values["access_control"] = access_control
         if auto_delete_objects is not None:
@@ -421,13 +361,15 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
             self._values["website_routing_rules"] = website_routing_rules
 
     @builtins.property
-    def access_control(self) -> typing.Optional[aws_cdk.aws_s3.BucketAccessControl]:
+    def access_control(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl]:
         '''Specifies a canned ACL that grants predefined permissions to the bucket.
 
         :default: BucketAccessControl.PRIVATE
         '''
         result = self._values.get("access_control")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketAccessControl], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl], result)
 
     @builtins.property
     def auto_delete_objects(self) -> typing.Optional[builtins.bool]:
@@ -446,7 +388,9 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def block_public_access(self) -> typing.Optional[aws_cdk.aws_s3.BlockPublicAccess]:
+    def block_public_access(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess]:
         '''The block public access configuration of this bucket.
 
         :default: - CloudFormation defaults will apply. New buckets and objects don't allow public access, but users can modify bucket policies or object permissions to allow public access
@@ -454,7 +398,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html
         '''
         result = self._values.get("block_public_access")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BlockPublicAccess], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess], result)
 
     @builtins.property
     def bucket_key_enabled(self) -> typing.Optional[builtins.bool]:
@@ -477,7 +421,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def cors(self) -> typing.Optional[typing.List[aws_cdk.aws_s3.CorsRule]]:
+    def cors(self) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.CorsRule]]:
         '''The CORS configuration of this bucket.
 
         :default: - No CORS configuration.
@@ -485,10 +429,10 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-cors.html
         '''
         result = self._values.get("cors")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.CorsRule]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.CorsRule]], result)
 
     @builtins.property
-    def encryption(self) -> typing.Optional[aws_cdk.aws_s3.BucketEncryption]:
+    def encryption(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption]:
         '''The kind of server-side encryption to apply to this bucket.
 
         If you choose KMS, you can specify a KMS key via ``encryptionKey``. If
@@ -497,10 +441,10 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :default: - ``Kms`` if ``encryptionKey`` is specified, or ``Unencrypted`` otherwise.
         '''
         result = self._values.get("encryption")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketEncryption], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey]:
         '''External KMS key to use for bucket encryption.
 
         The 'encryption' property must be either not specified or set to "Kms".
@@ -513,7 +457,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         a new KMS key will be created and associated with this bucket.
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey], result)
 
     @builtins.property
     def enforce_ssl(self) -> typing.Optional[builtins.bool]:
@@ -540,7 +484,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
     @builtins.property
     def intelligent_tiering_configurations(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_s3.IntelligentTieringConfiguration]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration]]:
         '''Inteligent Tiering Configurations.
 
         :default: No Intelligent Tiiering Configurations.
@@ -548,10 +492,12 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AmazonS3/latest/userguide/intelligent-tiering.html
         '''
         result = self._values.get("intelligent_tiering_configurations")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.IntelligentTieringConfiguration]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration]], result)
 
     @builtins.property
-    def inventories(self) -> typing.Optional[typing.List[aws_cdk.aws_s3.Inventory]]:
+    def inventories(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.Inventory]]:
         '''The inventory configuration of the bucket.
 
         :default: - No inventory configuration
@@ -559,21 +505,23 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-inventory.html
         '''
         result = self._values.get("inventories")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.Inventory]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.Inventory]], result)
 
     @builtins.property
     def lifecycle_rules(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_s3.LifecycleRule]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.LifecycleRule]]:
         '''Rules that define how Amazon S3 manages objects during their lifetime.
 
         :default: - No lifecycle rules.
         '''
         result = self._values.get("lifecycle_rules")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.LifecycleRule]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.LifecycleRule]], result)
 
     @builtins.property
-    def metrics(self) -> typing.Optional[typing.List[aws_cdk.aws_s3.BucketMetrics]]:
+    def metrics(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.BucketMetrics]]:
         '''The metrics configuration of this bucket.
 
         :default: - No metrics configuration.
@@ -581,10 +529,12 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-metricsconfiguration.html
         '''
         result = self._values.get("metrics")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.BucketMetrics]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.BucketMetrics]], result)
 
     @builtins.property
-    def object_ownership(self) -> typing.Optional[aws_cdk.aws_s3.ObjectOwnership]:
+    def object_ownership(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership]:
         '''The objectOwnership of the bucket.
 
         :default: - No ObjectOwnership configuration, uploading account will own the object.
@@ -592,7 +542,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :see: https://docs.aws.amazon.com/AmazonS3/latest/dev/about-object-ownership.html
         '''
         result = self._values.get("object_ownership")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.ObjectOwnership], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership], result)
 
     @builtins.property
     def public_read_access(self) -> typing.Optional[builtins.bool]:
@@ -606,22 +556,24 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy]:
         '''Policy to apply when the bucket is removed from this stack.
 
         :default: - The bucket will be orphaned.
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.RemovalPolicy], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy], result)
 
     @builtins.property
-    def server_access_logs_bucket(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def server_access_logs_bucket(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Destination bucket for the server access logs.
 
         :default: - If "serverAccessLogsPrefix" undefined - access logs disabled, otherwise - log to current bucket.
         '''
         result = self._values.get("server_access_logs_bucket")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     @builtins.property
     def server_access_logs_prefix(self) -> typing.Optional[builtins.str]:
@@ -671,7 +623,9 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def website_redirect(self) -> typing.Optional[aws_cdk.aws_s3.RedirectTarget]:
+    def website_redirect(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.RedirectTarget]:
         '''Specifies the redirect behavior of all requests to a website endpoint of a bucket.
 
         If you specify this property, you can't specify "websiteIndexDocument", "websiteErrorDocument" nor , "websiteRoutingRules".
@@ -679,18 +633,18 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :default: - No redirection.
         '''
         result = self._values.get("website_redirect")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.RedirectTarget], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.RedirectTarget], result)
 
     @builtins.property
     def website_routing_rules(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_s3.RoutingRule]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.RoutingRule]]:
         '''Rules that define when a redirect is applied and the redirect behavior.
 
         :default: - No redirection rules.
         '''
         result = self._values.get("website_routing_rules")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.RoutingRule]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.RoutingRule]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -710,3 +664,67 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__12c21179f9e7bb44a50659259407e96dc6e1f1b6b4428f047f629d9fe45b16e0(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    access_control: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl] = None,
+    auto_delete_objects: typing.Optional[builtins.bool] = None,
+    block_public_access: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess] = None,
+    bucket_key_enabled: typing.Optional[builtins.bool] = None,
+    bucket_name: typing.Optional[builtins.str] = None,
+    cors: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.CorsRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+    encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+    enforce_ssl: typing.Optional[builtins.bool] = None,
+    event_bridge_enabled: typing.Optional[builtins.bool] = None,
+    intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration, typing.Dict[builtins.str, typing.Any]]]] = None,
+    inventories: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.Inventory, typing.Dict[builtins.str, typing.Any]]]] = None,
+    lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+    metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
+    object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
+    public_read_access: typing.Optional[builtins.bool] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    server_access_logs_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    server_access_logs_prefix: typing.Optional[builtins.str] = None,
+    transfer_acceleration: typing.Optional[builtins.bool] = None,
+    versioned: typing.Optional[builtins.bool] = None,
+    website_error_document: typing.Optional[builtins.str] = None,
+    website_index_document: typing.Optional[builtins.str] = None,
+    website_redirect: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.RedirectTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_routing_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.RoutingRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ef6f15d7c98db0989a25fa7ab8edef4a7fd55f4e92e2f77044d0f0c4ca58d2b(
+    *,
+    access_control: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketAccessControl] = None,
+    auto_delete_objects: typing.Optional[builtins.bool] = None,
+    block_public_access: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BlockPublicAccess] = None,
+    bucket_key_enabled: typing.Optional[builtins.bool] = None,
+    bucket_name: typing.Optional[builtins.str] = None,
+    cors: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.CorsRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+    encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey] = None,
+    enforce_ssl: typing.Optional[builtins.bool] = None,
+    event_bridge_enabled: typing.Optional[builtins.bool] = None,
+    intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.IntelligentTieringConfiguration, typing.Dict[builtins.str, typing.Any]]]] = None,
+    inventories: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.Inventory, typing.Dict[builtins.str, typing.Any]]]] = None,
+    lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.LifecycleRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+    metrics: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketMetrics, typing.Dict[builtins.str, typing.Any]]]] = None,
+    object_ownership: typing.Optional[_aws_cdk_aws_s3_ceddda9d.ObjectOwnership] = None,
+    public_read_access: typing.Optional[builtins.bool] = None,
+    removal_policy: typing.Optional[_aws_cdk_ceddda9d.RemovalPolicy] = None,
+    server_access_logs_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    server_access_logs_prefix: typing.Optional[builtins.str] = None,
+    transfer_acceleration: typing.Optional[builtins.bool] = None,
+    versioned: typing.Optional[builtins.bool] = None,
+    website_error_document: typing.Optional[builtins.str] = None,
+    website_index_document: typing.Optional[builtins.str] = None,
+    website_redirect: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.RedirectTarget, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_routing_rules: typing.Optional[typing.Sequence[typing.Union[_aws_cdk_aws_s3_ceddda9d.RoutingRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
